@@ -165,6 +165,7 @@ class JsonObject:
             new_object = cls_or_self()
         else:
             new_object = cls_or_self
+
         for key in json_dictionary:
             member = getattr(new_object, key)
             it = type(member)
@@ -329,7 +330,6 @@ class JsonList(list):
         exec(criteria, d)
         return self.filter(d["criteria"])
 
-
     def split_by(self, m) -> dict:
         if type(m) is str and issubclass(self.list_type, JsonObject) :
             d = {}
@@ -425,9 +425,7 @@ class JsonList(list):
         from numpy import array
         if self.list_type is int or self.list_type is float or self.list_type is bool:
             return array(self)
-        if issubclass(self.list_type, JsonObject):
-            return array([i.get_values() for i in self])
-        raise "Numpy conversion can only be done on typed json lists with types float, int, bool or JsonObject"
+        return array([i.get_values() for i in self if isinstance(i, JsonObject)])
 
     def from_numpy_array(self, a):
         self.clear()
@@ -451,3 +449,18 @@ class JsonList(list):
             for c in columns:
                 ni[c] = row[c]
             self.append(ni)
+
+
+class JsonString(str):
+    def __new__(cls, string=""):
+        if string:
+            try:
+                o = JsonObject.load(string)
+                instance = super().__new__(cls, str(o))
+                setattr(instance, "value", o)
+            except:
+                instance = super().__new__(cls, string)
+                setattr(instance, "value", None)
+        else:
+            instance = super().__new__(cls)
+        return instance
